@@ -32,7 +32,13 @@ class ImageWrapper:
         reference_size = max(self.original_size)
         scale_factor = self.max_dimension() / reference_size
         new_size = (int(image.size[0] * scale_factor), int(image.size[1] * scale_factor))
-        self.resized_image = image.resize(new_size)
+        try:
+            self.resized_image = image.resize(new_size)
+            self.valid = True
+        except OSError as err:
+            print(f"{err} for {file}")
+            self.resized_image = None
+            self.valid = False
 
     @property
     def original_image(self) -> Image.Image:
