@@ -12,6 +12,21 @@ def parse_command_line() -> Namespace:
         'root_directory', default='.', nargs='+',
         help="The root of the directory tree under which images are compared"
     )
+    parser.add_argument(
+        '--algorithm', choices=COMPARISON_METHODS.keys(),
+        default='exact',
+        help="Method used to determine if two images are considered equal"
+    )
+    parser.add_argument(
+        '--on-equal', choices=ACTIONS_ON_EQUALITY.keys(),
+        default='print', help="command to be run on each pair of images found to be equal"
+    )
+    parser.add_argument(
+        '--parallel', action='store_true', help="Filter using all available cores (Experimental)"
+    )
+    parser.add_argument(
+        '--chunk-size', type=int, help="Chunk size for parallelization"
+    )
     parser.add_argument(
         '--fuzziness', '-f', default=0.001, type=float,
         help="Maximum deviation (RMS) of the histograms of two images still considered equal"
@@ -20,18 +35,5 @@ def parse_command_line() -> Namespace:
         '--aspect-fuzziness', default=0.05, type=float,
         help="Maximum difference in aspect ratios of two images to compare more closely"
     )
-    parser.add_argument(
-        '--algorithm', choices=COMPARISON_METHODS.keys(),
-        default='exact',
-        help="Method used to determine if two images are considered equal"
-    )
-    parser.add_argument(
-        '--action-equal', choices=ACTIONS_ON_EQUALITY.keys(),
-        default='view', help="command to be run on each pair of images found to be equal"
-    )
-    parser.add_argument(
-        '--parallel', action='store_true', help="Filter using all available cores (Experimental)"
-    )
-    parser.add_argument('--chunk-size', type=int, help="Chunk size for parallelization")
 
     return parser.parse_args()
